@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 package Opsview::RestAPI::Exception;
-$Opsview::RestAPI::Exception::VERSION = '1.180580';
+$Opsview::RestAPI::Exception::VERSION = '1.181000';
 # ABSTRACT: Opsview::RestAPI Exception object
 
 
@@ -16,15 +16,20 @@ use overload
 
 sub new {
     my ( $class, %args ) = @_;
-    ( $args{package}, $args{path}, $args{line} ) = caller 0;
 
-    return bless {%args}, $class;
+    my @caller_keys
+        = (
+        qw/ package filename line subroutine hasargs wantarray evaltext is_require hints bitmask hinthash /
+        );
+
+    bless { %args, map { $caller_keys[$_] => ( caller(0) )[$_] } ( 0 .. 10 ), }, $class;
 }
 
 
-sub line { $_[0]->{line} };
-sub path { $_[0]->{path} };
-sub package { $_[0]->{package} };
+sub line     { $_[0]->{line} }
+sub path     { $_[0]->{filename} }
+sub filename { $_[0]->{filename} }
+sub package  { $_[0]->{package} }
 
 
 sub message {
@@ -39,8 +44,8 @@ sub http_code {
 
 sub as_string {
     my $self = shift;
-    return sprintf( "%s at %s line %s.",
-        $self->{message}, $self->{path}, $self->{line} );
+    return sprintf( "%s at %s line %s.\n",
+        $self->message, $self->path, $self->line );
 }
 
 
@@ -58,7 +63,7 @@ Opsview::RestAPI::Exception - Opsview::RestAPI Exception object
 
 =head1 VERSION
 
-version 1.180580
+version 1.181000
 
 =head1 SYNOPSIS
 
@@ -81,10 +86,14 @@ Exception objects created when Opsview::RestAPI encountered problems
 
 =item $object = Opsview::RestAPI::Exception->new( ... )
 
-Create a new exception object.  By default will add in package, path and line the exception occurred on
+Create a new exception object.  By default will add in package, filename and line the exception occurred on
 
 =item $line = $object->line;
+
 =item $path = $object->path;
+
+=item $filename = $object->filename;
+
 =item $package = $object->package;
 
 Return the line, path and package the exception occurred in
